@@ -26,17 +26,28 @@
 #'  }
 label_eurostat <- function(x, dic = NULL, code = NULL, eu_order = FALSE, 
                            lang = "en"){
+
   if (is_tibble(x)){
     y <- x
-    for (i in names(y)[!(names(y) %in% c("time", "values","flags"))]){
-      y[[i]] <- label_eurostat(y[[i]], i, eu_order = eu_order, lang = lang)
+
+    mynams <- names(y)[!(names(y) %in% c("time", "values","flags"))]
+    for (i in mynams){
+      l <- label_eurostat(y[[i]], i, eu_order = eu_order, lang = lang)
+      y[[i]] <- as.vector(unlist(l)) 
     }
-    
+
+    # Fix the first two variables
+    #nams <- names(y)
+    #y <- cbind(as.vector(unlist(x[[1]])),
+    #           as.vector(unlist(x[[2]])),
+    #	       x[, 3:ncol(x)])
+    #colnames(y) <- nams
+
     # Codes added if asked
     if (!is.null(code)){
       code_in <- code %in% names(y)
       if (!all(code_in)) stop("code column name(s) ", shQuote(code[!code_in])," not found on x")
-      y_code <- x[, code, drop = FALSE]
+      y_code <- x[, code, drop = FALSE]            
       names(y_code) <- paste0(names(y_code), "_code")
       y <- cbind(y_code, y)
     }
@@ -46,7 +57,6 @@ label_eurostat <- function(x, dic = NULL, code = NULL, eu_order = FALSE,
 
     dic_df <- get_eurostat_dic(dic, lang = lang)
 
-
     if (is.factor(x)){
       if (eu_order) {
         ord <- dic_order(levels(x), dic_df, "code")
@@ -56,6 +66,7 @@ label_eurostat <- function(x, dic = NULL, code = NULL, eu_order = FALSE,
       
       y <- factor(x, levels(x)[ord], 
                   labels = dic_df[[2]][match(levels(x), dic_df[[1]])][ord])
+      
     } else {
       # dics are in upper case, change if x is not
       test_n <- min(length(x), 5)
@@ -65,8 +76,20 @@ label_eurostat <- function(x, dic = NULL, code = NULL, eu_order = FALSE,
     }
 
     if (any(is.na(y))) warning("All labels for ", dic, " were not found.")
+    
   }
+
+  # Ensure the output is tbl_df
+  #if (length(y) > 1) {
+  #  y <- as_data_frame(y)
+  #}
+  if (is.data.frame(y) && length(y) > 1) {
+    y <- as_data_frame(y)
+  }  
+  
+  
   y
+
 }
   
 #' @describeIn label_eurostat Get definitions for variable (column) names. For
