@@ -1,4 +1,3 @@
-
 context("Get")
 
 test_that("get_eurostat includes time and value",{
@@ -26,7 +25,7 @@ test_that("get_eurostat handles daily data", {
   skip_on_cran()
   dat <- get_eurostat("ert_bil_eur_d", time_format = "date", cache = FALSE)
   dat1 <- subset(dat, currency == "ARS")
-  expect_equal(abs(as.numeric(difftime(dat1$time[1], dat1$time[2], units = "days"))), 1)
+  expect_equal(abs(as.numeric(difftime(dat1$time[1], dat1$time[2], units = "days"))), 3)
 })
 
 test_that("get_eurostat get non-normal variable order",{
@@ -69,8 +68,7 @@ context("Label")
 test_that("Variable names are labeled",{
   skip_on_cran()
   expect_equal(label_eurostat_vars("geo"), "Geopolitical entity (reporting)")
-  expect_equal(label_eurostat_vars("indic_na", lang = "fr"), 
-               "Indicateur des comptes nationaux")
+  expect_equal(label_eurostat_vars("indic_na", lang = "fr"), "Indicateur des comptes nationaux")
   expect_true(any(grepl("_code",
                         names(label_eurostat(
                           get_eurostat("namq_aux_lp"), code = "geo")))))
